@@ -39,8 +39,6 @@ class FileServerConnector:
     Context = HttpServerConnector.Context
 
     def __init__(self, config: Config, context: Context):
-        self._config = config
-        self._context = context
         self._connector = HttpServerConnector(config, context)
 
     async def get_file(self, file_id: str, range_: Optional[str] = None) -> bytes:
